# About batch

<img src="https://gitlab.com/octomy/batch/-/raw/master/design/batch-logo-1024.png" width="20%"/>

Batch is a batch tasks queue and executor


Batch is [available on gitlab](https://gitlab.com/octomy/batch).
Batch is [available in PyPI](https://pypi.org/project/batch/).

```shell
# Install batch into your current Python environment
pip install octomy-batch

```




